View source: R/get_custom_palette.R
| get_custom_palette | R Documentation |
Returns a vector of distinct colors for use in plotting or annotation. Uses a predefined set of base colors and interpolates additional colors if needed.
get_custom_palette(n)
n |
Integer. Number of colors required. |
A character vector of length n containing hexadecimal color codes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.